@@ -426,8 +426,41 @@ def captital_number(value, yuan="圆", digits="零壹贰叁肆伍陆柒捌玖",
 
     return result
 
-def camel(value):
-    words = split(value, ["-", "_", " "])
-    words = [x.capitalize() for x in words]
-    return "".join(words)
+def clean(value, clean_chars):
+    if not isinstance(clean_chars, set):
+        clean_chars = set(clean_chars)
+    value2 = ""
+    for c in value:
+        if c in clean_chars:
+            value2 += c
+    return value2
 
+def camel(value, **kwargs):
+    """named-paramters: clean:bool=False, clean_chars:string=string.ascii_letters + string.digits
+    """
+    do_clean = kwargs.get("clean", False)
+    clean_chars = kwargs.get("clean_chars", string.ascii_letters + string.digits)
+    words = []
+    word_chars = set(string.ascii_letters)
+    word = ""
+    non_word = ""
+    for c in value:
+        if c in word_chars:
+            word += c
+            if non_word:
+                words.append(non_word)
+                non_word = ""
+        else:
+            non_word += c
+            if word:
+                words.append(word.capitalize())
+                word = ""
+    if word:
+        words.append(word.capitalize())
+    if non_word:
+        words.append(non_word)
+    if do_clean:
+        clean_chars = set(clean_chars)
+        return "".join([clean(x, clean_chars) for x in words])
+    else:
+        return "".join(words)
